@@ -91,7 +91,7 @@ To create an instance of the interface object, using default values
 for all configuration options:
 
   use UMLS::Association;
-  my $associator = UMLS::Association->new();
+  my $associaton = UMLS::Association->new();
 
 Database connection options can be passed through the my.cnf file. For 
 example: 
@@ -170,7 +170,7 @@ my $pkg = "UMLS::Association";
 
 use vars qw($VERSION);
 
-$VERSION = '0.03';
+$VERSION = '0.05';
 
 my $debug = 0;
 
